==> nsn-9.2.2-en-download.zip: nsn-9.2.2-en/webhelp/nsn-webhelp/navig/contents.js <==
//
//	FindinSite-CD-JS-HelpIndex database supernatural
//
//	Copyright (c) 2016-2023 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var supernatural = {
    baseurls: ["../"],
    varname: "supernatural",
        tree: [
            { url: "about/about.htm", title: "About this Documentation",
              tree: [
                  { url: "about/document_conventions.htm", title: "Document Conventions" },
                  { url: "about/online_information.htm", title: "Online Information and Support" },
                  { url: "about/data_protection.htm", title: "Data Protection" },
              ]
            },
            { url: "install/instover.htm", title: "Installation and Set-Up",
              tree: [
                  { url: "install/nsn_installation.htm", title: "Installing Super Natural on Mainframes" },
                  { url: "install/setup3.htm", title: "Setting up Super Natural" },
              ]
            },
            { url: "tutorial/tutover.htm", title: "Tutorial",
              tree: [
                  { url: "tutorial/nsn_about_tutorial.htm", title: "About this Tutorial" },
                  { url: "tutorial/basic2.htm", title: "Sample 1: Basic Transaction" },
                  { url: "tutorial/work3.htm", title: "Sample 2: Worksheet" },
                  { url: "tutorial/userf4.htm", title: "Sample 3: User Fields, Calculation and Logical Conditions Editors" },
                  { url: "tutorial/mode5.htm", title: "Sample 4: Modes and User File" },
                  { url: "tutorial/layout6.htm", title: "Sample 5: Layout Editor" },
                  { url: "tutorial/flink7.htm", title: "Sample 6: File Link" },
                  { url: "tutorial/lookup8.htm", title: "Sample 7: File Lookup" },
                  { url: "tutorial/dynam9.htm", title: "Sample 8: Dynamic Input Fields" },
                  { url: "tutorial/rpc1.htm", title: "Sample 9: RPC Service in Context Mode with Primary, Secondary and Lookup files" },
                  { url: "tutorial/rpc2.htm", title: "Sample 10: RPC Service in Context Mode with Dynamic Input" },
                  { url: "tutorial/rpc3.htm", title: "Sample 11: RPC Service in Direct Mode with Summary Functionality" },
              ]
            },
            { url: "ug/ugover.htm", title: "User's Guide",
              tree: [
                  { url: "ug/what2.htm", title: "Introducing Super Natural" },
                  { url: "ug/using3.htm", title: "Using Super Natural" },
                  { url: "ug/start4.htm", title: "Starting Up" },
                  { url: "ug/trans5.htm", title: "Using Reporting Transactions" },
                  { url: "ug/work6.htm", title: "Working with the Worksheet" },
                  { url: "ug/dbstruc7.htm", title: "Using a Database Structure" },
                  { url: "ug/files8.htm", title: "Defining Files" },
                  { url: "ug/fields9.htm", title: "Defining Fields" },
                  { url: "ug/edit10.htm", title: "Using Editors" },
                  { url: "ug/rptm11.htm", title: "Working with Natural Report Manager" },
                  { url: "ug/proto12.htm", title: "Working with Prototype Programs" },
                  { url: "ug/rpc.htm", title: "Using the Super Natural RPC Service" },
                  { url: "ug/exit13.htm", title: "Using User Exit Programs" },
                  { url: "ug/prof14.htm", title: "Adjusting a User Profile" },
                  { url: "ug/trpt15.htm", title: "Defining Transaction Modes for Reporting" },
                  { url: "ug/tdmain16.htm", title: "Defining Transaction Modes for Data Maintenance" },
                  { url: "ug/appl17.htm", title: "Working with Application Programs" },
                  { url: "ug/con18.htm", title: "Using Super Natural with Con-nect" },
                  { url: "ug/usrf19.htm", title: "Working with User Files" },
                  { url: "ug/dmain20.htm", title: "Working with Data Maintenance Transactions" },
                  { url: "ug/a-cmd.htm", title: "Command List" },
                  { url: "ug/b-sv.htm", title: "System Variables" },
                  { url: "ug/d-em.htm", title: "Edit Masks" },
              ]
            },
            { url: "admin/admover.htm", title: "Administration",
              tree: [
                  { url: "admin/intro2.htm", title: "Introduction" },
                  { url: "admin/user3.htm", title: "Users" },
                  { url: "admin/fil4.htm", title: "Files" },
                  { url: "admin/super5.htm", title: "Superfiles" },
                  { url: "admin/userf6.htm", title: "User Files" },
                  { url: "admin/lib7.htm", title: "Libraries" },
                  { url: "admin/comm8.htm", title: "Common Library Definitions" },
                  { url: "admin/spec9.htm", title: "Special Services" },
                  { url: "admin/bat10.htm", title: "Batch Processing" },
                  { url: "admin/butil11.htm", title: "Batch Utilities" },
                  { url: "admin/exit12.htm", title: "Exit Programs" },
                  { url: "admin/tech13.htm", title: "Technical Information" },
              ]
            },
            { url: "glossary/glossary.htm", title: "Glossary" },
            { url: "general/legal.htm", title: "Copyright" },
        ]
};

var mainProject = 1;

$.event.trigger({ type: "fishidbloaded", db: supernatural });

==> nsn-9.2.4-en-download.zip: nsn-9.2.4-en/webhelp/nsn-webhelp/navig/contents.js <==
//
//	FindinSite-CD-JS-HelpIndex database supernatural
//
//	Copyright (c) 2016-2025 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var supernatural = {
    baseurls: ["../"],
    varname: "supernatural",
        tree: [
            { url: "about/about.htm", title: "About this Documentation",
              tree: [
                  { url: "about/document_conventions.htm", title: "Document Conventions" },
                  { url: "about/online_information.htm", title: "Online Information and Support" },
                  { url: "about/data_protection.htm", title: "Data Protection" },
              ]
            },
            { url: "relnotes/relnotes.htm", title: "Super Natural Release Notes",
              tree: [
                  { url: "relnotes/critical.htm", title: "Critical Changes" },
              ]
            },
            { url: "install/instover.htm", title: "Installation and Set-Up",
              tree: [
                  { url: "install/nsn_installation.htm", title: "Installing Super Natural on Mainframes" },
                  { url: "install/setup3.htm", title: "Setting up Super Natural" },
              ]
            },
            { url: "tutorial/tutover.htm", title: "Tutorial",
              tree: [
                  { url: "tutorial/nsn_about_tutorial.htm", title: "About this Tutorial" },
                  { url: "tutorial/basic2.htm", title: "Sample 1: Basic Transaction" },
                  { url: "tutorial/work3.htm", title: "Sample 2: Worksheet" },
                  { url: "tutorial/userf4.htm", title: "Sample 3: User Fields, Calculation and Logical Conditions Editors" },
                  { url: "tutorial/mode5.htm", title: "Sample 4: Modes and User File" },
                  { url: "tutorial/layout6.htm", title: "Sample 5: Layout Editor" },
                  { url: "tutorial/flink7.htm", title: "Sample 6: File Link" },
                  { url: "tutorial/lookup8.htm", title: "Sample 7: File Lookup" },
                  { url: "tutorial/dynam9.htm", title: "Sample 8: Dynamic Input Fields" },
                  { url: "tutorial/rpc1.htm", title: "Sample 9: RPC Service in Context Mode with Primary, Secondary and Lookup files" },
                  { url: "tutorial/rpc2.htm", title: "Sample 10: RPC Service in Context Mode with Dynamic Input" },
                  { url: "tutorial/rpc3.htm", title: "Sample 11: RPC Service in Direct Mode with Summary Functionality" },
              ]
            },
            { url: "ug/ugover.htm", title: "User's Guide",
              tree: [
                  { url: "ug/what2.htm", title: "Introducing Super Natural" },
                  { url: "ug/using3.htm", title: "Using Super Natural" },
                  { url: "ug/start4.htm", title: "Starting Up" },
                  { url: "ug/trans5.htm", title: "Using Reporting Transactions" },
                  { url: "ug/work6.htm", title: "Working with the Worksheet" },
                  { url: "ug/dbstruc7.htm", title: "Using a Database Structure" },
                  { url: "ug/files8.htm", title: "Defining Files" },
                  { url: "ug/fields9.htm", title: "Defining Fields" },
                  { url: "ug/edit10.htm", title: "Using Editors" },
                  { url: "ug/rptm11.htm", title: "Working with Natural Report Manager" },
                  { url: "ug/proto12.htm", title: "Working with Prototype Programs" },
                  { url: "ug/rpc.htm", title: "Using the Super Natural RPC Service" },
                  { url: "ug/exit13.htm", title: "Using User Exit Programs" },
                  { url: "ug/prof14.htm", title: "Adjusting a User Profile" },
                  { url: "ug/trpt15.htm", title: "Defining Transaction Modes for Reporting" },
                  { url: "ug/tdmain16.htm", title: "Defining Transaction Modes for Data Maintenance" },
                  { url: "ug/appl17.htm", title: "Working with Application Programs" },
                  { url: "ug/usrf19.htm", title: "Working with User Files" },
                  { url: "ug/dmain20.htm", title: "Working with Data Maintenance Transactions" },
                  { url: "ug/a-cmd.htm", title: "Command List" },
                  { url: "ug/b-sv.htm", title: "System Variables" },
                  { url: "ug/d-em.htm", title: "Edit Masks" },
              ]
            },
            { url: "admin/admover.htm", title: "Administration",
              tree: [
                  { url: "admin/intro2.htm", title: "Introduction" },
                  { url: "admin/user3.htm", title: "Users" },
                  { url: "admin/fil4.htm", title: "Files" },
                  { url: "admin/super5.htm", title: "Superfiles" },
                  { url: "admin/userf6.htm", title: "User Files" },
                  { url: "admin/lib7.htm", title: "Libraries" },
                  { url: "admin/comm8.htm", title: "Common Library Definitions" },
                  { url: "admin/spec9.htm", title: "Special Services" },
                  { url: "admin/bat10.htm", title: "Batch Processing" },
                  { url: "admin/butil11.htm", title: "Batch Utilities" },
                  { url: "admin/exit12.htm", title: "Exit Programs" },
                  { url: "admin/tech13.htm", title: "Technical Information" },
              ]
            },
            { url: "glossary/glossary.htm", title: "Glossary" },
            { url: "general/legal.htm", title: "Copyright" },
        ]
};

var mainProject = 1;

$.event.trigger({ type: "fishidbloaded", db: supernatural });
